Index: third_party/WebKit/LayoutTests/resources/testharnessreport.js |
diff --git a/third_party/WebKit/LayoutTests/resources/testharnessreport.js b/third_party/WebKit/LayoutTests/resources/testharnessreport.js |
index 1d3d729d3da39ad30c7b92f3b1e07e9e94d82c7d..72ddacd0dd14cc9aa158cbc3765a827f92ebad72 100644 |
--- a/third_party/WebKit/LayoutTests/resources/testharnessreport.js |
+++ b/third_party/WebKit/LayoutTests/resources/testharnessreport.js |
@@ -78,9 +78,11 @@ |
function isWPTManualTest() { |
var path = location.pathname; |
- if (location.hostname == 'web-platform.test' && path.endsWith('-manual.html')) |
+ if (location.hostname == 'web-platform.test' |
+ && /.*-manual(\.https)?\.html$/.test(path)) { |
return true; |
- return /\/external\/wpt\/.*-manual\.html$/.test(path); |
+ } |
+ return /\/external\/wpt\/.*-manual(\.https)?\.html$/.test(path); |
} |
// Returns a directory part relative to WPT root and a basename part of the |
@@ -113,8 +115,10 @@ |
} |
var src; |
- if (pathAndBase.startsWith('/fullscreen/')) { |
- // Fullscreen tests all use the same automation script. |
+ if (pathAndBase.startsWith('/fullscreen/') |
+ || pathAndBase.startsWith('/webusb/')) { |
+ // Fullscreen tests all use the same automation script and WebUSB |
+ // tests borrow it. |
src = automationPath + '/fullscreen/auto-click.js'; |
} else if (pathAndBase.startsWith('/pointerevents/') |
|| pathAndBase.startsWith('/uievents/') |
@@ -268,5 +272,4 @@ |
window.addEventListener('load', done); |
} |
}); |
- |
})(); |